@@ -8,7 +8,11 @@
  */
 
 #include "boxes.h"
+#ifndef OLD_CURSES
+#include <ncurses.h>
+#else
 #include <curses.h>
+#endif
 
 
 void
