@@ -11,7 +11,11 @@
 #include "buttons.h"
 #include "boxes.h"
 #include "textwindow.h"
+#ifndef OLD_CURSES
+#include <ncurses.h>
+#else
 #include <curses.h>
+#endif
 
 
 void
