@@ -9,10 +9,14 @@
 
 #include "mainmenu.h"
 #include "splashscr.h"
-#include <curses.h>
 #include <signal.h>
 #include <unistd.h>
 #include <string.h>
+#ifndef OLD_CURSES
+#include <ncurses.h>
+#else
+#include <curses.h>
+#endif
 
 
 void
