@@ -23,10 +23,14 @@
 #include "fmtheaders.h"
 #include "signpr_main.h"
 
-#include <curses.h>
 #include <stdlib.h>
 #include <sys/stat.h>
 #include <string.h>
+#ifndef OLD_CURSES
+#include <ncurses.h>
+#else
+#include <curses.h>
+#endif
 
 
 void
