@@ -12,7 +12,11 @@
 #include "errorwindow.h"
 #include <stdlib.h>
 #include <stdio.h>
+#ifndef OLD_CURSES
+#include <ncurses.h>
+#else
 #include <curses.h>
+#endif
 
 
 void
