@@ -30,8 +30,13 @@
 #include "yesnowindow.h"
 #include <stdlib.h>
 #include <stdio.h>
-#include <curses.h>
 #include <math.h>
+#ifndef OLD_CURSES
+#include <ncurses.h>
+#else
+#include <curses.h>
+#endif
+
 
 /* Macros I used first:
 
@@ -555,6 +560,8 @@ cond_median_highpass (long offset, long offset_zero,
   sum.left = 0;
   sum.right = 0;
 
+#define notTEST_DAVE_PLATT
+#ifndef TEST_DAVE_PLATT
   sample = get_from_buffer (&parampointer->buffer, offset - 1);
   sum.left += sample.left;
   sum.right += sample.right;
@@ -567,6 +574,25 @@ cond_median_highpass (long offset, long offset_zero,
 
   sum.left /= 4;
   sum.right /= 4;
+#else
+  /* Testing, suggested by Dave Platt. Invert phase of one channel, then
+     do tick detection using the sum signal. This is because most ticks
+     are out-of-phase signals. I've not really tested this - it might
+     require other settings for thresholds etc. */
+  sample = get_from_buffer (&parampointer->buffer, offset - 1);
+  sum.left += sample.left;
+  sum.left -= sample.right;
+  sample = get_from_buffer (&parampointer->buffer, offset);
+  sum.left -= 2 * (long) sample.left;
+  sum.left += 2 * (long) sample.right;
+  sample = get_from_buffer (&parampointer->buffer, offset + 1);
+  sum.left += sample.left;
+  sum.left -= sample.right;
+
+  /* just in case L/R: 32000/-32000 -32000/32000 32000/-32000 : */
+  sum.left /= 8;
+  sum.right = sum.left;
+#endif /* TEST_DAVE_PLATT */
 
   sample.left = sum.left;
   sample.right = sum.right;
@@ -669,13 +695,13 @@ cond_median_filter (parampointer_t parampointer)
 
 #ifdef VIEW_INTERNALS
 
-  returnval.left = b_t.left;
+  returnval.left = b_t.left * 10;
 
   if (
        (labs (w_t.left - b_t.left) * 1000)
        /
        b_t.left > parampointer->long1)
-    returnval.right = 10000;
+    returnval.right = 2000;
   else
     returnval.right = 0;
 
