@@ -16,9 +16,13 @@
 #define FOURTH_ORDER
 #define noSIXTH_ORDER
 
+/* To use the (slow) fancy interpolation routine, define FANCY_FILL here */
+#define noFANCY_FILL
+
 
 #include "signpr_cmf2.h"
 #include "signpr_general.h"
+#include "signpr_l1fit.h"
 #include "errorwindow.h"
 #include "stringinput.h"
 #include "buttons.h"
@@ -28,8 +32,12 @@
 #include "yesnowindow.h"
 #include <stdlib.h>
 #include <stdio.h>
-#include <curses.h>
 #include <math.h>
+#ifndef OLD_CURSES
+#include <ncurses.h>
+#else
+#include <curses.h>
+#endif
 
 
 void
@@ -576,7 +584,8 @@ cond_median2_highpass (long offset, long offset_zero,
   /* Testing, suggested by Dave Platt. Invert phase of one channel, then
      do tick detection using the sum signal. This is because most ticks
      are out-of-phase signals. I've not really tested this - it might
-     require other settings for thresholds etc. */
+     require other settings for thresholds etc.
+     Note: implemented for second_order only! */
   sample = get_from_buffer (&parampointer->buffer, offset - 1);
   sum.left += sample.left;
   sum.left -= sample.right;
@@ -774,6 +783,12 @@ cond_median2_filter (parampointer_t parampointer)
   /* max. length if toleft=postlength4 and toright=prelength4 */
   signed short list3[2 * (parampointer->postlength4 +
 			  parampointer->prelength4 + 1) + 1];
+#ifdef FANCY_FILL
+  signed short list4[2 * (parampointer->postlength4 +
+			  parampointer->prelength4 + 1) + 1];
+  double a1, b1;
+#endif
+
   long i;
   int toleft, toright;
   signed short maxval;
@@ -842,12 +857,23 @@ cond_median2_filter (parampointer_t parampointer)
 
 #ifdef VIEW_INTERNALS
 	  returnval.left = (toright + toleft + 1) * 500;
+#else
+#ifdef FANCY_FILL
+	  for (i = 0; i <= 2 * (toleft + toright + 1); i++)
+	    {
+	      list3[i] = get_from_buffer (&parampointer->buffer,
+					  i - (toleft + toright + 1)).left;
+	      list4[i] = i - (toleft + toright + 1);
+	    }
+	  l1fit (list4, list3, 2 * (toleft + toright + 1), &a1, &b1);
+	  returnval.left = (signed short) rint (a1);
 #else
 	  for (i = 0; i <= 2 * (toleft + toright + 1); i++)
 	    list3[i] = get_from_buffer (&parampointer->buffer,
 					i - (toleft + toright + 1)).left;
 
 	  returnval.left = median (list3, 2 * (toleft + toright + 1) + 1);
+#endif
 #endif
 	}
     }
@@ -899,12 +925,23 @@ cond_median2_filter (parampointer_t parampointer)
 
 #ifdef VIEW_INTERNALS
 	  returnval.right = (toright + toleft + 1) * 500;
+#else
+#ifdef FANCY_FILL
+	  for (i = 0; i <= 2 * (toleft + toright + 1); i++)
+	    {
+	      list3[i] = get_from_buffer (&parampointer->buffer,
+					  i - (toleft + toright + 1)).right;
+	      list4[i] = i - (toleft + toright + 1);
+	    }
+	  l1fit (list4, list3, 2 * (toleft + toright + 1), &a1, &b1);
+	  returnval.right = (signed short) rint (a1);
 #else
 	  for (i = 0; i <= 2 * (toleft + toright + 1); i++)
 	    list3[i] = get_from_buffer (&parampointer->buffer,
 					i - (toleft + toright + 1)).right;
 
 	  returnval.right = median (list3, 2 * (toleft + toright + 1) + 1);
+#endif
 #endif
 	}
     }
