@@ -8,9 +8,13 @@
  */
 
 #include "textwindow.h"
-#include <curses.h>
 #include <stdlib.h>
 #include <string.h>
+#ifndef OLD_CURSES
+#include <ncurses.h>
+#else
+#include <curses.h>
+#endif
 
 
 void
