@@ -19,9 +19,13 @@
 
 #include <sys/stat.h>
 #include <stdlib.h>
-#include <curses.h>
 #include <math.h>
 #include <string.h>
+#ifndef OLD_CURSES
+#include <ncurses.h>
+#else
+#include <curses.h>
+#endif
 
 
 int
