@@ -16,7 +16,11 @@
 #include "helpline.h"
 #include <stdlib.h>
 #include <stdio.h>
+#ifndef OLD_CURSES
+#include <ncurses.h>
+#else
 #include <curses.h>
+#endif
 
 
 int
